from enum import StrEnum


class BwaTag(StrEnum):
    """
    BWA-specific optional fields.

    https://bio-bwa.sourceforge.net/bwa.shtml
    """

    X0 = "X0"
    """
    Number of best hits.
    """

    X1 = "X1"
    """
    Number of suboptimal hits found by BWA.
    """

    XN = "XN"
    """
    Number of ambiguous bases in the reference.
    """

    XM = "XM"
    """
    Number of mismatches in the alignment.
    """

    XO = "XO"
    """
    Number of gap opens.

    Note that XO and XG are generated by BWT search while the CIGAR string by Smith-Waterman
    alignment. These two tags may be inconsistent with the CIGAR string. This is not a bug.
    """

    XG = "XG"
    """
    Number of gap extensions.

    Note that XO and XG are generated by BWT search while the CIGAR string by Smith-Waterman
    alignment. These two tags may be inconsistent with the CIGAR string. This is not a bug.
    """

    XT = "XT"
    """
    Type: Unique/Repeat/N/Mate-sw.
    """

    XA = "XA"
    """
    Alternative hits; format: (chr,pos,CIGAR,NM;)*

    The maximum number of alignments output in the `XA` tag is controlled by the `-n INT` flag in
    `bwa samse` and `bwa sampe`. If a read has more than INT hits, the `XA` tag will not be written.
    """

    XS = "XS"
    """
    Suboptimal alignment score.
    """

    XF = "XF"
    """
    Support from forward/reverse alignment.
    """

    XE = "XE"
    """
    Number of supporting seeds.
    """
